@@ -31,7 +31,7 @@ Example:
 
 import json
 
-from luigi.file import LocalTarget
+from luigi.local_target import LocalTarget
 from luigi.mock import MockTarget
 from luigi.contrib.s3 import S3Target
 from luigi.target import FileSystemException
